%
% soar(x1,x2,L)
% 
%
% function to compute correlation between two points x1, x1 according to 
% their separation
%
% if x1 and x2 are vectors of length m and n then c will be a (mxn) 
% correlation matrix.
%
% uses a SOAR correlation function with length scale L (L = 0 =>
% uncorrelated)
%
%   rho = [1 + (dx/L)]*exp(-dx/L); dx = |x1-x2|
%
% P.J. Smith July 2014
% -------------------------------------------------------------------------


function c = soar2(x1,x2,L)

dim1 = length(x1);
dim2 = length(x2);

c = zeros(dim1,dim2);

for i=1:dim1
    
   xi = x1(i);
   
 for j=1:dim2   

  xj = x2(j);
  d = abs(xi-xj);

 if (d==0)
  c(i,j) = 1.0;
 elseif L > 0.0
  c(i,j) = (1.0 + d/L)*exp(-d/L);
 else
  c(i,j) = 0.0;
 end  

 end % for xj
end % for xi

end